package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.sql.Connection;
import java.util.HashSet;
import java.util.Set;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/ProcedureAccessAction.class */
public class ProcedureAccessAction extends LifeJDBCAction {
    private String procedureDefine;
    private String procedureDefineField;
    private boolean throwException = true;
    private Set errorCodeSet = new HashSet();

    public String execute(Context context) throws GENEException {
        int result;
        Connection connection = null;
        try {
            String procName = this.procedureDefineField == null ? this.procedureDefine : (String) context.getDataValue(this.procedureDefineField);
            connection = LifeDBAccess.getConnection(getDataSource());
            String retCode = LifeDBAccess.executeProcedure(context, connection, procName);
            try {
                result = Integer.parseInt(retCode);
            } catch (NumberFormatException unused) {
                result = -1;
            }
            if (result != 0) {
                Trace.logWarning("LifeAction", retCode);
                throw new TranFailException(retCode, false);
            }
            LifeDBAccess.releaseConnection(getDataSource(), connection);
            return retCode;
        } catch (Exception ex) {
            handleException(context, new TranFailException("EBLN0000", ex), this.throwException);
            return "0";
        } catch (TranFailException ex2) {
            if (this.errorCodeSet.contains(ex2.getErrorCode())) {
                return ex2.getErrorCode();
            }
            handleException(context, ex2, this.throwException);
            return "0";
        } finally {
            LifeDBAccess.releaseConnection(getDataSource(), connection);
        }
    }

    public void setProcedureDefine(String procedureDefine) {
        this.procedureDefine = procedureDefine;
    }

    public void setThrowException(String throwException) {
        this.throwException = Boolean.valueOf(throwException).booleanValue();
    }

    public void setProcedureDefineField(String procedureDefineField) {
        this.procedureDefineField = procedureDefineField;
    }

    public void setErrorCode(String errorCodeList) {
        StringTokenizer toke = new StringTokenizer(errorCodeList, "||");
        while (toke.hasMoreElements()) {
            String errorCode = ((String) toke.nextElement()).trim();
            this.errorCodeSet.add(errorCode);
        }
    }
}
